| intersubject_similarity | R Documentation |
This function runs an intersubject similarity analysis to determine if there is a relationship between similarity in FC and similarity in one or multiple outcomes.
intersubject_similarity(FC_data, outcome, mode = "diff", nperm = 1000)
FC_data |
An N x E matrix containing the vectorized edges; where N = number of subjects, E=number of edges |
outcome |
A numerical vector (single outcome) or matrix (multiple outcomes) containing the values of the outcome(s) of interest |
mode |
When set to |
nperm |
number of permutations for the correlation test between FC similarity and outcome similarity |
This function runs an intersubject similarity analysis to determine if there is a relationship between similarity in FC and similarity in one or multiple outcomes. The outcome(s) will be z-standardized prior to calculating the intersubject similarity in the outcome(s).
A list object containing
FC_difference_matrix The FC difference matrix
Outcome_difference_matrix The outcome difference matrix
permutation_data The permuted correlation values
demomat=get('demomat')
results=intersubject_similarity(FC_data = demomat, outcome=c(1,1,2,2),mode="diff")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.