View source: R/network_level_lme.R
| network_lme | R Documentation |
mass univariate linear mixed effects analysis at the network level
network_lme(
model,
contrast,
random,
FC_data,
threshold.method = "fdr",
perm = TRUE,
nperm = 1000,
perm_type = "within_between",
nthread = 4
)
model |
A data.frame or matrix containing all the predictors in the model |
contrast |
The predictor of interest. The edge- and network-wise statistics will only be estimated for this predictor |
random |
A N x 1 numeric vector or object containing the values of the random variable (optional). Its length should be equal to the number of subjects in model (it should NOT be inside the model data.frame). |
FC_data |
An N x E matrix containing the vectorized edges; where N = number of subjects, E=number of edges |
threshold.method |
method for correcting for multiple tests. set to |
perm |
If set to |
nperm |
number of permutations to use if |
perm_type |
A string object specifying whether to permute the rows ("row"), between subjects ("between"), within subjects ("within") or between and within subjects ("within_between") for random subject effects. Default is "row". |
nthread |
The number of CPU threads to use. Default is 4. |
This function first summarizes the FC edges into their respective networks and then carry out mass univariate linear mixed effect analyses on each of the network to network connection
A data.frame object with coef and corrected p values
demomat=get('demomat')[,1:7021]
contrast=c(1,1,2,2)
random=c('sub1','sub2','sub3','sub4')
model1=network_lme(model=contrast,
contrast=contrast,
random=random,
FC_data=demomat,
nperm=1,
nthread=2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.