| NBS | R Documentation |
Network-based statistics analysis
NBS(model, contrast, FC_data, nperm = 100, nthread = 1, p = 0.001)
model |
A data.frame or matrix containing all the predictors in the model |
contrast |
The predictor of interest. The edge- and network-wise statistics will only be estimated for this predictor |
FC_data |
An N x E matrix containing the vectorized edges; where N = number of subjects, E=number of edges |
nperm |
The number of permutations to generate the null distribution of network strengths. Set to 100 by default |
nthread |
The number of CPU threads to use. Set to 1 by default |
p |
the edge-wise threshold. Set to 0.001 by default |
This function implements the NBS analysis described in Zalesky et al. (2010) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.neuroimage.2010.06.041")}
A list object containing
results Edge- and network-wise results in a data.frame object
t.orig Edge-wise t-stats
tcrit The critical t-value
max.netstr A vector containing the null distribution of the permuted network strengths
demomat=get('demomat')[,1:7021]
contrast=c(1,1,2,2)
random=c('sub1','sub2','sub3','sub4')
model1=NBS(model=contrast,
contrast=contrast,
FC_data=demomat,
nperm=2,
nthread=2,
p=0.001)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.