edges_to_networks: edges_to_networks

View source: R/edges2network.R

edges_to_networksR Documentation

edges_to_networks

Description

convert an edge level FC matrix into a network level FC matrix

Usage

edges_to_networks(FCmat)

Arguments

FCmat

an FC matrix or vector

Details

This function first identifies the unique network pairs in the appropriate FC atlas and then averages the edges within each of the network pairs

Value

A network level FC matrix

Examples

edges_to_networks(runif(23871))


FCtools documentation built on Sept. 15, 2026, 5:09 p.m.