View source: R/edges2network.R
| edges_to_networks | R Documentation |
convert an edge level FC matrix into a network level FC matrix
edges_to_networks(FCmat)
FCmat |
an FC matrix or vector |
This function first identifies the unique network pairs in the appropriate FC atlas and then averages the edges within each of the network pairs
A network level FC matrix
edges_to_networks(runif(23871))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.