intersubject_similarity
intersubject_similarity.RdThis function runs an intersubject similarity analysis to determine if there is a relationship between similarity in FC and similarity in one or multiple outcomes.
Arguments
- FC_data
An N x E matrix containing the vectorized edges; where N = number of subjects, E=number of edges
- outcome
A numerical vector (single outcome) or matrix (multiple outcomes) containing the values of the outcome(s) of interest
- mode
When set to
"diff", FC similarity is calculated as absolute difference between the FC vectors of a pair of subjects. When set to"corr",FC similarity is calculated as 1 - (pearson's correlation coefficient between the FC vectors of a pair of subjects). Set to"diff"by default.- nperm
number of permutations for the correlation test between FC similarity and outcome similarity
Value
a list object containing
FC_difference_matrixThe FC difference matrixOutcome_difference_matrixThe outcome difference matrixpermutation_dataThe permuted correlation values