network_lm
network_lm.Rdmass univariate linear regression at the network level
Arguments
- model
A data.frame or matrix containing all the predictors in the model
- contrast
The predictor of interest. The edge- and network-wise statistics will only be estimated for this predictor
- FC_data
An N x E matrix containing the vectorized edges; where N = number of subjects, E=number of edges
- threshold.method
method for correcting for multiple tests. set to
fdrby default- perm
If set to
TRUE, p values will be calculated using a permutation approach by shuffling subjects' labels, before correcting for FDR. Set toTRUEby default- nperm
number of permutations to use if
perm=T.