View source: R/vizGlassbrain.R
| vizGlassbrain | R Documentation |
Visualizing brain connectivity with a glass brain plot
vizGlassbrain(
data,
surf_color = "grey",
node_color = "#00BA38",
surf_alpha = 0.2,
cmap,
node_size = 8,
node_label = TRUE,
node_label_size = 10,
node_label_color = "black",
edgethickness = 8,
limits,
colorbar_title = "Connectivity strength",
orientation_labels = TRUE,
remove_brain = FALSE
)
data |
a vector of edge values with a length of 4005, 7021, 23871 or 30135 |
surf_color |
color of the cortical surface. Set to |
node_color |
color of the nodes. Set to |
surf_alpha |
alpha value of the cortical surface, where 0 will cause the cortical surface to disappear and 1 will cause the cortical surface to be completely opaque. Set to |
cmap |
A string vector containing 2 to 3 color names/codes specifying the colors to be used for the color scale. See |
node_size |
size parameter for the dots representing the nodes. Set to |
node_label |
option to show node labels. Set to |
node_label_size |
font size of the node labels. Set to |
node_label_color |
font color of the node labels. Set to |
edgethickness |
a value to adjust the thickness of the edges. Set to |
limits |
Numeric vector of length 2, composed of the lower and upper color scale limits of the plot. When left unspecified, the symmetrical limits |
colorbar_title |
title for the colorbar legend. Set to |
orientation_labels |
A boolean object specifying if orientation labels are to be displayed. Set to |
remove_brain |
A boolean object specifying cortical surface should be removed. Set to |
This function takes a vector of edge values and visualizes the edge-to-edge connectivity with a glass brain plot
A plot_ly object
mask=sample(c(1,0), 7021, replace = TRUE, prob = c(0.001, 0.999))
data=runif(7021,min = -1,max=1)*mask
vizGlassbrain(data,orientation_labels = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.